package sialocacao.teste.disciplina;

/**
 * <p>Title: DisciplinaTeste.java </p>
 * <p>Description: Casos de teste para Disciplina. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */


import java.util.*;

import junit.framework.*;

import sialocacao.*;

import sialocacao.disciplina.*;
import sialocacao.disciplina.excecoes.*;


public class DisciplinaTeste extends TestCase {

  private Disciplina disciplina1;
  private Disciplina disciplina2;
  private Disciplina disciplina3;
  private Disciplina disciplina4;

  protected void setUp() {
    disciplina1 = new Disciplina(0, "Engenharia de Software", 40, "Eng Soft", "ES");
    disciplina2 = new Disciplina(0, "Sistemas Distribuidos", 30, "SD", "RSD");
    disciplina3 = new Disciplina(0, "Banco Dados", 45, "Data Base", "BD");
    disciplina4 = new Disciplina(0, "Linguagens de Programacao", 50,"Lig Prog", "LP");
  }


  /**
   * Caso de teste que cadastra a disciplina e em seguida verifica se a
   * mesma foi realmente cadastrada.
   *
   */
  public void testeCadastrarDisicplina()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();
      sialocacao.inserirDisciplina(disciplina1.getDescricao(),
                                   disciplina1.getCargaHoraria(),
                                   disciplina1.getEmenta(),
                                   disciplina1.getArea());
      Disciplina disciplinaRet =
          sialocacao.buscarDisciplina(disciplina1.getDescricao());

      disciplinaRet.setCodigo(0);

      Assert.assertTrue("Falha em cadastrar disciplina", disciplinaRet.equals(disciplina1));

    } catch ( Exception e ) {
      fail("Falha em cadastrar disciplina");
    }
  }

  /**
   * Caso de teste que cadastra uma disciplina e em seguida recupera e exclui
   * a mesma do banco.
   *
   */
  public void testeExcluirDisciplina()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();
      sialocacao.inserirDisciplina(disciplina2.getDescricao(),
                                   disciplina2.getCargaHoraria(),
                                   disciplina2.getEmenta(),
                                   disciplina2.getArea());

      Disciplina disciplinaRet =
          sialocacao.buscarDisciplina(disciplina2.getDescricao());

      sialocacao.excluirDisciplina(disciplinaRet.getCodigo());

      try {
        sialocacao.buscarDisciplina(disciplina2.getDescricao());
        Assert.assertTrue("Falha em excluir disciplina", false);
      } catch (DisciplinaInexistenteException e) {
        return;
      }
    } catch ( Exception e ) {
      fail("Falha em excluir disciplina");
    }
  }

  /**
   * Caso de teste que cadastra uma disciplina, recupera a disciplina cadastrada
   * e em seguida altera os dados da mesma.
   *
   */
  public void testeAlterarDisciplina()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();

      sialocacao.inserirDisciplina(disciplina3.getDescricao(),
                                   disciplina3.getCargaHoraria(),
                                   disciplina3.getEmenta(),
                                   disciplina3.getArea());

      Disciplina disciplinaRet =
          sialocacao.buscarDisciplina(disciplina3.getDescricao());

      Disciplina disciplinaAlterada = disciplinaRet;

      disciplinaAlterada.setArea("IA");

      sialocacao.alterarDisciplina(disciplinaAlterada);

      disciplinaRet =
          sialocacao.buscarDisciplina(disciplinaAlterada.getDescricao());

      Assert.assertTrue("Falha em alterar disciplina",
                        disciplinaRet.equals(disciplinaAlterada));

    } catch ( Exception e ) {
      fail("Falha em alterar disciplina");
    }
  }

  /**
   * Caso de teste que cadastra uma disciplina, cria um array com todas as
   * disciplinas cadastradas e em seguida, verifica se a disicplina recem
   * cadastrada esta presente no array.
   *
   */
  public void testeListarDisciplinas()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();

      sialocacao.inserirDisciplina(disciplina4.getDescricao(),
                                   disciplina4.getCargaHoraria(),
                                   disciplina4.getEmenta(),
                                   disciplina4.getArea());


      ArrayList disciplinas = sialocacao.listarDisciplinas();

      Disciplina disciplinaRet;
      for (int i = 0; i < disciplinas.size(); i++) {
        disciplinaRet = (Disciplina) disciplinas.get(i);
        disciplina4.setCodigo(disciplinaRet.getCodigo()); // Desconsidera o codigo
        if(disciplina4.equals(disciplinaRet)){
          return;
        }
      }
      Assert.assertTrue("Falha em listar disciplinas", false);
    } catch ( Exception e ) {
      fail("Falha em listar disciplinas");
    }
  }
}
