package sialocacao.teste.horario;

/**
 * <p>Title: HorarioTeste.java </p>
 * <p>Description: Casos de teste para Horario. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */


import java.util.*;

import junit.framework.*;

import sialocacao.*;

import sialocacao.horario.*;
import sialocacao.horario.excecoes.*;


public class HorarioTeste extends TestCase {

  private Horario horario1;
  private Horario horario2;
  private Horario horario3;
  private Horario horario4;

  protected void setUp() {
    horario1 = new Horario(0, "SEG", "08:00", "10:00");
    horario2 = new Horario(0, "TER", "10:00", "12:00");
    horario3 = new Horario(0, "QUA", "12:00", "14:00");
    horario4 = new Horario(0, "QUI", "14:00", "16:00");
  }


  /**
   * Caso de teste que cadastra um horario e em seguida verifica se o
   * mesmo foi realmente cadastrado.
   *
   */
  public void testeCadastrarHorario()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();

      sialocacao.inserirHorario(horario1.getDiaDaSemana(),
                                horario1.getHoraInicio(),
                                horario1.getHoraFim());

      Horario horarioRet =
          sialocacao.buscarHorario(horario1.getDiaDaSemana(),
                                   horario1.getHoraInicio(),
                                   horario1.getHoraFim());

      horarioRet.setCodigo(0);

      Assert.assertTrue("Falha em cadastrar horario", horarioRet.equals(horario1));

    } catch ( Exception e ) {
      fail("Falha em cadastrar horario");
    }
  }

  /**
   * Caso de teste que cadastra um horario e em seguida recupera e exclui
   * o mesmo do banco.
   *
   */
  public void testeExcluirHorario()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();

      sialocacao.inserirHorario(horario2.getDiaDaSemana(),
                                horario2.getHoraInicio(),
                                horario2.getHoraFim());


      Horario horarioRet =
          sialocacao.buscarHorario(horario2.getDiaDaSemana(),
                                   horario2.getHoraInicio(),
                                   horario2.getHoraFim());


      sialocacao.excluirHorario(horarioRet.getCodigo());

      try {
        sialocacao.buscarHorario(horario2.getDiaDaSemana(),
                                 horario2.getHoraInicio(),
                                 horario2.getHoraFim());

        Assert.assertTrue("Falha em excluir horario", false);
      } catch (HorarioInexistenteException e) {
        return;
      }
    } catch ( Exception e ) {
      fail("Falha em excluir horario");
    }
  }

  /**
   * Caso de teste que cadastra um horario, recupera o horario cadastrado
   * e em seguida altera os dados do mesmo.
   *
   */
  public void testeAlterarHorario()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();

      sialocacao.inserirHorario(horario3.getDiaDaSemana(),
                                horario3.getHoraInicio(),
                                horario3.getHoraFim());


      Horario horarioRet =
          sialocacao.buscarHorario(horario3.getDiaDaSemana(),
                                   horario3.getHoraInicio(),
                                   horario3.getHoraFim());


      Horario horarioAlterado = horarioRet;

      horarioAlterado.setDiaDaSemana("SEX");

      sialocacao.alterarHorario(horarioAlterado);


      horarioRet = sialocacao.buscarHorario(horarioAlterado.getDiaDaSemana(),
                                            horarioAlterado.getHoraInicio(),
                                            horarioAlterado.getHoraFim());

      Assert.assertTrue("Falha em alterar horario",
                        horarioRet.equals(horarioAlterado));

    } catch ( Exception e ) {
      fail("Falha em alterar horario");
    }
  }

  /**
   * Caso de teste que cadastra um horario, cria um array com todos os
   * horarios cadastrados e em seguida, verifica se o horario recem
   * cadastrado esta presente no array.
   *
   */
  public void testeListarHorario()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();

      sialocacao.inserirHorario(horario4.getDiaDaSemana(),
                                horario4.getHoraInicio(),
                                horario4.getHoraFim());

      ArrayList horarios = sialocacao.listarHorarios();

      Horario horarioRet;
      for (int i = 0; i < horarios.size(); i++) {
        horarioRet = (Horario) horarios.get(i);
        horario4.setCodigo(horarioRet.getCodigo()); // Desconsidera o codigo
        if(horario4.equals(horarioRet)){
          return;
        }
      }
      Assert.assertTrue("Falha em listar horarios", false);
    } catch ( Exception e ) {
      fail("Falha em listar horarios");
    }
  }
}
