package sialocacao.teste.professor;

/**
 * <p>Title: ProfessorTeste.java </p>
 * <p>Description: Casos de teste para Professor. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */


import java.util.*;

import junit.framework.*;

import sialocacao.*;

import sialocacao.professor.*;
import sialocacao.professor.excecoes.*;


public class ProfessorTeste extends TestCase {

  private Professor professor1;
  private Professor professor2;
  private Professor professor3;
  private Professor professor4;

  protected void setUp() {
    professor1 = new Professor(0, "Silvio Meira", "Engenharia de Software");
    professor2 = new Professor(0, "Jones", "Engenharia de Software");
    professor3 = new Professor(0, "Carlos Ferraz", "Sistemas Distribuidos");
    professor4 = new Professor(0, "Paulo Borba", "Engenharia de Software");
  }


  /**
   * Caso de teste que cadastra o professor e em seguida verifica se o
   * professor foi realmente cadastrado.
   *
   */
  public void testeCadastrarProfessor()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();
      sialocacao.inserirProfessor(professor1.getNome(), professor1.getArea());
      Professor professorRet = sialocacao.buscarProfessor(professor1.getNome());
      professorRet.setCodigo(0);
      Assert.assertTrue("Falha em cadastrar professor", professorRet.equals(professor1));
    } catch ( Exception e ) {
      fail("Falha em cadastrar professor");
    }
  }

  /**
   * Caso de teste que cadastra o professor e em seguida verifica exclui
   * o professor cadastrado.
   *
   */
  public void testeExcluirProfessor()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();
      sialocacao.inserirProfessor(professor2.getNome(), professor2.getArea());
      Professor professorRet = sialocacao.buscarProfessor(professor2.getNome());
      sialocacao.excluirProfessor(professorRet.getCodigo());
      try {
        sialocacao.buscarProfessor(professor2.getNome());
        Assert.assertTrue("Falha em excluir professor", false);
      } catch (ProfessorInexistenteException e) {
        return;
      }
    } catch ( Exception e ) {
      fail("Falha em excluir professor");
    }
  }

  /**
   * Caso de teste que cadastra o professor, recupera o professor cadastrado
   * e em seguida altera os dados do mesmo.
   *
   */
  public void testeAlterarProfessor()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();
      sialocacao.inserirProfessor(professor3.getNome(), professor3.getArea());
      Professor professorRet = sialocacao.buscarProfessor(professor3.getNome());
      Professor professorAlterado = professorRet;
      professorAlterado.setArea("Inteligencia Artificial");
      sialocacao.alterarProfessor(professorAlterado);
      professorRet = sialocacao.buscarProfessor(professorAlterado.getNome());
      Assert.assertTrue("Falha em alterar professor", professorAlterado.equals(professorRet));

    } catch ( Exception e ) {
      fail("Falha em alterar professor");
    }
  }

  /**
   * Caso de teste que cadastra o professor, cria um array com todos os
   * professores cadastrado e em seguida, verifica se o professor cadastrado
   * esta presente no array.
   *
   */
  public void testeListarProfessores()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();
      sialocacao.inserirProfessor(professor4.getNome(), professor4.getArea());

      ArrayList professores = sialocacao.listarProfessores();
      Professor professoRet;
      for (int i = 0; i < professores.size(); i++) {
        professoRet = (Professor) professores.get(i);
        professor4.setCodigo(professoRet.getCodigo()); // Desconsidera o codigo
        if(professor4.equals(professoRet)){
          return;
        }
      }
      Assert.assertTrue("Falha em listar professor", false);
    } catch ( Exception e ) {
      fail("Falha em listar professor");
    }
  }
}