package sialocacao.teste.sala;

/**
 * <p>Title: SalaTeste.java </p>
 * <p>Description: Casos de teste para Sala. </p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: Fbrica III </p>
 * @author: Carlos A. Rego Andrade
 *          Fbio de Carvalho Dias Ferreira
 *          Luiz Eduardo Cunha Leite
 *          Taciana Amorim Vanderlei
 *          Vivianne da Nbrega Medeiros
 * @version 1.0
 */


import java.util.*;

import junit.framework.*;

import sialocacao.*;

import sialocacao.sala.*;
import sialocacao.sala.excecoes.*;


public class SalaTeste extends TestCase {

  private Sala sala1;
  private Sala sala2;
  private Sala sala3;
  private Sala sala4;

  protected void setUp() {
    sala1 = new Sala(0, "A1", "CIN", "Nenhum");
    sala2 = new Sala(0, "A2", "CIN", "Quadro Branco");
    sala3 = new Sala(0, "A3", "CIN", "Data Show");
    sala4 = new Sala(0, "A4", "CIN", "Televisor");
  }


  /**
   * Caso de teste que cadastra a sala e em seguida verifica se a
   * mesma foi realmente cadastrada.
   *
   */
  public void testeCadastrarSala()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();

      sialocacao.inserirSala( sala1.getDescricao(),
                              sala1.getLocalizacao(),
                              sala1.getObservacao());

      Sala salaRet =
          sialocacao.buscarSala(sala1.getDescricao());

      salaRet.setCodigo(0);

      Assert.assertTrue("Falha em cadastrar sala", salaRet.equals(sala1));

    } catch ( Exception e ) {
      fail("Falha em cadastrar sala");
    }
  }

  /**
   * Caso de teste que cadastra uma sala e em seguida recupera e exclui
   * a mesma do banco.
   *
   */
  public void testeExcluirSala()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();

      sialocacao.inserirSala( sala2.getDescricao(),
                              sala2.getLocalizacao(),
                              sala2.getObservacao());

      Sala salaRet =
          sialocacao.buscarSala(sala2.getDescricao());


      sialocacao.excluirSala(salaRet.getCodigo());

      try {
        sialocacao.buscarSala(sala2.getDescricao());
        Assert.assertTrue("Falha em excluir sala", false);
      } catch (SalaInexistenteException e) {
        return;
      }
    } catch ( Exception e ) {
      fail("Falha em excluir sala");
    }
  }

  /**
   * Caso de teste que cadastra uma sala, recupera a sala cadastrada
   * e em seguida altera os dados da mesma.
   *
   */
  public void testeAlterarSala()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();

      sialocacao.inserirSala( sala3.getDescricao(),
                              sala3.getLocalizacao(),
                              sala3.getObservacao());

      Sala salaRet =
          sialocacao.buscarSala(sala3.getDescricao());

      Sala salaAlterada = salaRet;

      salaAlterada.setLocalizacao("CT");

      sialocacao.alterarSala(salaAlterada);

      salaRet =
          sialocacao.buscarSala(salaAlterada.getDescricao());

      Assert.assertTrue("Falha em alterar sala",
                        salaRet.equals(salaAlterada));

    } catch ( Exception e ) {
      fail("Falha em alterar sala");
    }
  }

  /**
   * Caso de teste que cadastra uma sala, cria um array com todas as
   * salas cadastradas e em seguida, verifica se a sala recem
   * cadastrada esta presente no array.
   *
   */
  public void testeListarSalas()
  {
    try {
      SIAlocacao sialocacao = new SIAlocacao();

      sialocacao.inserirSala( sala4.getDescricao(),
                              sala4.getLocalizacao(),
                              sala4.getObservacao());



      ArrayList salas = sialocacao.listarSalas();

      Sala salaRet;
      for (int i = 0; i < salas.size(); i++) {
        salaRet = (Sala) salas.get(i);
        sala4.setCodigo(salaRet.getCodigo()); // Desconsidera o codigo
        if(sala4.equals(salaRet)){
          return;
        }
      }
      Assert.assertTrue("Falha em listar salas", false);
    } catch ( Exception e ) {
      fail("Falha em listar salas");
    }
  }
}
